Description Usage Arguments Value Examples
View source: R/scrape_thread.R
Scrape thread Returns the threads' content
1 | scrape_thread(suffix, quotes = TRUE)
|
quotes |
A logical vector indicating how the function should go across
quotes. If set to |
thread_link |
A character string. The thread's link. |
A tibble with a bunch of columns. thread contains the url
where you can find the thread containing the posting, date the date
the posting was created on, time the time it was created at,
content its textual content, and quote_ind indicates whether
it contains quoted content or not. Unfortunately, it is nearly impossible to
remove the quotes in a reasonable manner. If the function is successful,
postings without quotes (either because they did not contain one in the first
place or because the function worked properly) can be found in
content_wo_quote. If the function was not successful, the entries
where it failed at are also in this column – probably still contaning the
citation – and devtoolsstart with "!!!flawed citation!!!".
1 | scrape_thread("/Forum-27-260/m49908859.html", quote = FALSE)
|
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.